<template>
  <div class="bbsl-common-page"
       @click="commonPageClick">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam"
               :inline="true">
        <el-row :gutter="10">
          <el-col :span="6">
            <el-form-item label="设备名称">
              <el-input clearable
                        size="mini"
                        placeholder="请输入设备名称"
                        v-model="queryParam.params.name"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="6">
            <el-form-item label="启用状态">
              <el-select size="mini"
                         v-model="queryParam.params.status"
                         clearable
                         placeholder="请选择启用状态">
                <el-option v-for="item in statuss"
                           :key="item.id"
                           :label="item.name"
                           :value="item.value"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <!-- <el-col :span="6">
            <el-form-item label="设备代码">
              <el-input
                maxlength="18"
                size="mini"
                clearable
                placeholder="请输入编码"
                v-model="queryParam.params.code"
              ></el-input>
            </el-form-item>
          </el-col> -->
          <el-col :span="6">
            <el-form-item label="设备类型">
              <el-select size="mini"
                         v-model="queryParam.params.type"
                         clearable
                         placeholder="请选择设备类型">
                <el-option v-for="item in types"
                           :key="item.id"
                           :label="item.name"
                           :value="item.value"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item>
              <el-button type="primary"
                         icon="el-icon-search"
                         size="mini"
                         @click="onClickSearch">搜索</el-button>
              <el-button icon="el-icon-refresh"
                         size="mini"
                         @click="resetQuery">重置</el-button>
              <!-- <el-button type="text" @click.stop="openMore"
                >更多
                <i
                  :class="showMore ? 'el-icon-arrow-up' : 'el-icon-arrow-down'"
                ></i
              ></el-button> -->
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div class="bbsl-table-content"
         ref="contentPanel">
      <div class="bbsl-btn-content"
           ref="btnPanel">
        <el-button size="mini"
                   icon="el-icon-plus"
                   type="primary"
                   @click="openFormDiao">新增</el-button>
        <el-button :disabled="!multipleSelection.length"
                   size="mini"
                   icon="el-icon-delete"
                   type="danger"
                   @click="deleteSelect">删除</el-button>
      </div>
      <el-table stripe
                size="mini"
                :height="tableMaxHeight"
                @row-dblclick="handleDbClick"
                :style="{width: '100%'}"
                ref="multipleSelection"
                v-loading="loading"
                border
                :data="tableData"
                :row-key="getRowKey"
                @selection-change="handleSelectionChange"
                :header-cell-style="{'text-align': 'center'}"
                :cell-style="{'text-align': 'center'}">
        <el-table-column type="selection"
                         width="55"
                         :reserve-selection="true"></el-table-column>
        <el-table-column min-width="130"
                         fixed
                         sortable
                         prop="name"
                         label="设备名称"
                         show-overflow-tooltip></el-table-column>
        <el-table-column min-width="140"
                         sortable
                         prop="code"
                         label="设备代码"
                         show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="140"
                         sortable
                         prop="snNo"
                         label="设备SN值"
                         show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="160"
                         sortable
                         prop="objName"
                         label="设备对象分类"
                         show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="150"
                         sortable
                         prop="typeName"
                         label="设备类型"
                         show-overflow-tooltip></el-table-column>
        <el-table-column min-width="150"
                         sortable
                         prop="status"
                         label="启用状态"
                         show-overflow-tooltip>
          <template slot-scope="scope">
            <el-switch @change="changeStatus(scope.row)"
                       v-model="scope.row.status"
                       active-color="#13ce66"
                       inactive-color="#ff4949"
                       active-value="1"
                       inactive-value="0">
            </el-switch>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination ref="paginationPanel"
                     align="right"
                     class="bbsl-pagination"
                     background
                     @size-change="handleSizeChange"
                     @current-change="handleCurrentChange"
                     :current-page="queryParam.pageBean.page"
                     :page-sizes="[5, 10, 20, 50]"
                     :page-size="queryParam.pageBean.pageSize"
                     layout="total, sizes, prev, pager, next, jumper"
                     :total="total"></el-pagination>
    </div>
    <form-dialog v-if="showFormDia"
                 @closeFormDiao="closeFormDiao"
                 @refList="getDateList"
                 :showFormDia="showFormDia"
                 :title="title"
                 :pId="pId"></form-dialog>
  </div>
</template>
<script>
import FormDialog from './components/deviceForm-dialog.vue'
import deviceManger from '@/api/stManager/deviceManger.js'
import req from '@/request.js'
import { TableMixin } from '@/mixins/tableMixin'
export default {
  name: 'deviceManger',
  components: {
    FormDialog,
  },
  mixins: [TableMixin],
  data () {
    return {
      loading: false,
      multipleSelection: [], // 复选框
      queryParam: {
        pageBean: {
          pageSize: 10,
          page: 1,
        },
        params: {
          code: null,
          name: null,
          status: null,
          type: null,
          id: null,
        },
      },
      params: {
        id: null,
        status: null,
      },
      status: null,
      total: 0,
      title: '',
      showFormDia: false,
      tableData: [],
      pId: '',
      types: [],
      objIds: [],
      statuss: [
        { name: '禁用', value: '0' },
        { name: '启用', value: '1' },
      ],
      dikeGrads: [], //堤防级别
    }
  },
  created () {
    this.getSysDict();
  },
  methods: {
    // openMore() {
    //   this.showMore = !this.showMore
    // },
    //获取字典数据
    getSysDict () {
      let portal = window.context.portal
      return new Promise((resolve, reject) => {
        req.post(portal + '/sys/sysDictionary/v1/queryAllDictItems').then(
          (response) => {
            resolve(response.data)
            this.types = response.data.sblx;
            this.objIds = response.data.sbdxfl;
            this.getDateList();
          },
          (error) => {
            reject(error)
          }
        )
      })
    },
    getDateList () {
      this.loading = true;
      this.tableData = [];
      deviceManger.ListGet(this.queryParam, (res) => {
        this.total = res.value.total
        res.value.rows.forEach((ii) => {
          this.types.forEach((ee) => {
            if (ee.value == ii.type) {
              ii['typeName'] = ee.name;
            }
          })
          this.objIds.forEach((e) => {
            if (e.value == ii.type) {
              ii['objName'] = e.name;
            }
          })
        })
        this.tableData = JSON.parse(JSON.stringify(res.value.rows))
        this.$set(this.tableData)
        this.loading = false;
        console.log(this.tableData, '列表')
      })
    },
    changeStatus (val) {
      if (val.status) {
        this.params.status = '1'
        this.params.id = val.id
        deviceManger.getStatus(this.params, (res) => {
          if (res.state) {
            this.$notify({
              type: 'success',
              message: '修改成功',
              duration: 2000,
            })
          }
        })
      } else {
        this.params.status = '0'
        this.params.id = val.id
        deviceManger.getStatus(this.params, (res) => {
          if (res.state) {
            this.$notify({
              type: 'warning',
              message: '修改成功',
              duration: 2000,
            })
          }
        })
      }
    },
    openFormDiao () {
      this.title = '新增'
      this.showFormDia = true
    },
    closeFormDiao () {
      this.showFormDia = false
      this.getDateList()
    },
    handleSizeChange (val) {
      this.queryParam.pageBean.pageSize = val
      this.getDateList()
    },
    handleCurrentChange (val) {
      this.queryParam.pageBean.page = val
      this.getDateList()
    },
    // // 修改
    handleUpdate (row) {
      this.title = '修改'
      this.pId = row.id
      this.showFormDia = true
    },
    handleSelectionChange (val) {
      this.multipleSelection = val.map((item) => {
        return item.id
      })
    },
    // // 指定一个key标识这一行的数据
    getRowKey (row) {
      return row.id
    },
    // // 批量删除
    deleteSelect () {
      this.$confirm('确定删除选中数据？', '提示', {
        confirmButtonText: '确 定',
        cancelButtonText: '取 消',
        type: 'warning',
      })
        .then(() => {
          deviceManger
            .remove(this.multipleSelection, (res) => {
              if (res.state) {
                this.$notify({
                  type: 'success',
                  message: '删除成功',
                  duration: 2000,
                  // offset: 80
                })
                // this.multipleSelection = [];
                this.$refs.multipleSelection.clearSelection()
                this.queryParam.pageBean.page = 1
                this.getDateList()
              }
            })
            .catch((res) => {
              this.$notify({
                type: 'error',
                message: res.message,
                duration: 2000,
                offset: 80,
              })
              this.getDateList()
            })
        })
        .catch(() => { })
    },
    /** 删除按钮操作 */
    handleDelete (row) {
      this.$confirm('确定删除选中数据？', '提示', {
        confirmButtonText: '确 定',
        cancelButtonText: '取 消',
        type: 'warning',
      })
        .then(() => {
          deviceManger
            .remove(row.id, (res) => {
              if (res.state) {
                this.$notify({
                  type: 'success',
                  message: '删除成功',
                  duration: 2000,
                  // offset: 80
                })
                this.queryParam.pageBean.page = 1
                this.getDateList()
              }
            })
            .catch((res) => {
              this.$notify({
                type: 'error',
                message: res.message,
                duration: 2000,
                offset: 80,
              })
              this.getDateList()
            })
        })
        .catch(() => { })
    },
    // // 点击查询
    onClickSearch () {
      this.queryParam.pageBean.page = 1
      this.getDateList()
    },
    // 重置
    resetQuery () {
      this.queryParam.params = {}
      this.onClickSearch()
    },
  },
}
</script>
<style lang="scss" scoped>
.btn-content {
  display: flex;
}
.el-select-dropdown__item span {
  color: rgb(51, 51, 51) !important;
}
.el-select-dropdown__item {
  color: #9a9a9a !important;
}
.el-select-dropdown__item.hover,
.el-select-dropdown__item:hover {
  background: #f5f7fa;
}
.btn-content :first-child {
  margin: 0 0 0 0 !important;
}
.el-switch__label--left {
  position: relative;
  left: 45px;
  color: #fff;
  z-index: -1111;
}
.el-switch__core {
  width: 50px !important;
}
.el-switch__label--right {
  position: relative;
  right: 46px;
  color: #fff;
  z-index: -1111;
}
.el-switch__label--right.is-active {
  z-index: 1111;
  color: #fff !important;
}
.el-switch__label--left.is-active {
  z-index: 1111;
  color: #9c9c9c !important;
}
.sampling {
  ::v-deep .el-dialog__body {
    padding: 30px 20px 0 20px;
  }
}
::-webkit-scrollbar {
  background: #fff !important;
}
.bbsl-pagination {
  bottom: 10px !important;
}
</style>
